==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/MethodLocal.h <==
// class soot.jimple.toolkits.annotation.arraycheck.MethodLocal

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a53ec25e01edf44a soot_jimple_toolkits_annotation_arraycheck_MethodLocal

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_MethodLocal_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_MethodLocal_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Local$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$_init$197e354f306c7f2c(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$getLocal$a441b41cec934e4e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *);
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method_info$getLocal$a441b41cec934e4e;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getLocal$a441b41cec934e4e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *);
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vmethods	soot_jimple_toolkits_annotation_arraycheck_MethodLocal;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_refs {
	struct _jc_soot_SootMethod$object	*m;
	struct _jc_object	*l;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_refs	soot_jimple_toolkits_annotation_arraycheck_MethodLocal;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_MethodLocal;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_MethodLocal, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_MethodLocal_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/MethodLocal.h <==
// class soot.jimple.toolkits.annotation.arraycheck.MethodLocal

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a53ec25e01edf44a soot_jimple_toolkits_annotation_arraycheck_MethodLocal

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_MethodLocal_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_MethodLocal_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Local$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$_init$197e354f306c7f2c(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$getLocal$a441b41cec934e4e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method_info$getLocal$a441b41cec934e4e;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLocal$a441b41cec934e4e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vmethods	soot_jimple_toolkits_annotation_arraycheck_MethodLocal;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_refs {
	struct _jc_soot_SootMethod$object	*m;
	struct _jc_object	*l;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_refs	soot_jimple_toolkits_annotation_arraycheck_MethodLocal;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_MethodLocal;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_MethodLocal, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_MethodLocal$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_MethodLocal_H_ */
